<?php

namespace Karneaud\LavaliteKarneaudCargo\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Karneaud\LavaliteKarneaudCargo\Http\Requests\TblCourierOfficerRequest;
use Karneaud\LavaliteKarneaudCargo\Interfaces\TblCourierOfficerRepositoryInterface;
use Karneaud\LavaliteKarneaudCargo\Models\TblCourierOfficer;

/**
 * Resource controller class for tbl_courier_officer.
 */
class TblCourierOfficerResourceController extends BaseController
{

    /**
     * Initialize tbl_courier_officer resource controller.
     *
     * @param type TblCourierOfficerRepositoryInterface $tbl_courier_officer
     *
     * @return null
     */
    public function __construct(TblCourierOfficerRepositoryInterface $tbl_courier_officer)
    {
        parent::__construct();
        $this->repository = $tbl_courier_officer;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Karneaud\LavaliteKarneaudCargo\Repositories\Criteria\TblCourierOfficerResourceCriteria::class);
    }

    /**
     * Display a list of tbl_courier_officer.
     *
     * @return Response
     */
    public function index(TblCourierOfficerRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Karneaud\LavaliteKarneaudCargo\Repositories\Presenter\TblCourierOfficerPresenter::class)
                ->$function();
        }

        $tbl_courier_officers = $this->repository->paginate();

        return $this->response->title(trans('lavalite-karneaud-cargo::tbl_courier_officer.names'))
            ->view('lavalite-karneaud-cargo::tbl_courier_officer.index', true)
            ->data(compact('tbl_courier_officers', 'view'))
            ->output();
    }

    /**
     * Display tbl_courier_officer.
     *
     * @param Request $request
     * @param Model   $tbl_courier_officer
     *
     * @return Response
     */
    public function show(TblCourierOfficerRequest $request, TblCourierOfficer $tbl_courier_officer)
    {

        if ($tbl_courier_officer->exists) {
            $view = 'lavalite-karneaud-cargo::tbl_courier_officer.show';
        } else {
            $view = 'lavalite-karneaud-cargo::tbl_courier_officer.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('lavalite-karneaud-cargo::tbl_courier_officer.name'))
            ->data(compact('tbl_courier_officer'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new tbl_courier_officer.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TblCourierOfficerRequest $request)
    {

        $tbl_courier_officer = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('lavalite-karneaud-cargo::tbl_courier_officer.name')) 
            ->view('lavalite-karneaud-cargo::tbl_courier_officer.create', true) 
            ->data(compact('tbl_courier_officer'))
            ->output();
    }

    /**
     * Create new tbl_courier_officer.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TblCourierOfficerRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $tbl_courier_officer                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('lavalite-karneaud-cargo::tbl_courier_officer.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('lavalite-karneaud-cargo/tbl_courier_officer/' . $tbl_courier_officer->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/lavalite-karneaud-cargo/tbl_courier_officer'))
                ->redirect();
        }

    }

    /**
     * Show tbl_courier_officer for editing.
     *
     * @param Request $request
     * @param Model   $tbl_courier_officer
     *
     * @return Response
     */
    public function edit(TblCourierOfficerRequest $request, TblCourierOfficer $tbl_courier_officer)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('lavalite-karneaud-cargo::tbl_courier_officer.name'))
            ->view('lavalite-karneaud-cargo::tbl_courier_officer.edit', true)
            ->data(compact('tbl_courier_officer'))
            ->output();
    }

    /**
     * Update the tbl_courier_officer.
     *
     * @param Request $request
     * @param Model   $tbl_courier_officer
     *
     * @return Response
     */
    public function update(TblCourierOfficerRequest $request, TblCourierOfficer $tbl_courier_officer)
    {
        try {
            $attributes = $request->all();

            $tbl_courier_officer->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('lavalite-karneaud-cargo::tbl_courier_officer.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('lavalite-karneaud-cargo/tbl_courier_officer/' . $tbl_courier_officer->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('lavalite-karneaud-cargo/tbl_courier_officer/' . $tbl_courier_officer->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the tbl_courier_officer.
     *
     * @param Model   $tbl_courier_officer
     *
     * @return Response
     */
    public function destroy(TblCourierOfficerRequest $request, TblCourierOfficer $tbl_courier_officer)
    {
        try {

            $tbl_courier_officer->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('lavalite-karneaud-cargo::tbl_courier_officer.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('lavalite-karneaud-cargo/tbl_courier_officer/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('lavalite-karneaud-cargo/tbl_courier_officer/' . $tbl_courier_officer->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple tbl_courier_officer.
     *
     * @param Model   $tbl_courier_officer
     *
     * @return Response
     */
    public function delete(TblCourierOfficerRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('lavalite-karneaud-cargo::tbl_courier_officer.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('lavalite-karneaud-cargo/tbl_courier_officer'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/lavalite-karneaud-cargo/tbl_courier_officer'))
                ->redirect();
        }

    }

    /**
     * Restore deleted tbl_courier_officers.
     *
     * @param Model   $tbl_courier_officer
     *
     * @return Response
     */
    public function restore(TblCourierOfficerRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('lavalite-karneaud-cargo::tbl_courier_officer.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/lavalite-karneaud-cargo/tbl_courier_officer'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/lavalite-karneaud-cargo/tbl_courier_officer/'))
                ->redirect();
        }

    }

}
