<?php

namespace Karneaud\LavaliteKarneaudCargo\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Karneaud\LavaliteKarneaudCargo\Http\Requests\TblCourierOfficerRequest;
use Karneaud\LavaliteKarneaudCargo\Models\TblCourierOfficer;

/**
 * Admin web controller class.
 */
class TblCourierOfficerWorkflowController extends BaseController
{

    /**
     * Workflow controller function for tbl_courier_officer.
     *
     * @param Model   $tbl_courier_officer
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(TblCourierOfficerRequest $request, TblCourierOfficer $tbl_courier_officer, $step)
    {

        try {

            $tbl_courier_officer->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('lavalite-karneaud-cargo::tbl_courier_officer.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/tbl_courier_officer/tbl_courier_officer/' . $tbl_courier_officer->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/tbl_courier_officer/tbl_courier_officer/' . $tbl_courier_officer->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for tbl_courier_officer.
     *
     * @param Model   $tbl_courier_officer
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(TblCourierOfficer $tbl_courier_officer, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $tbl_courier_officer->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('lavalite-karneaud-cargo::tbl_courier_officer.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('lavalite-karneaud-cargo::admin.tbl_courier_officer.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('lavalite-karneaud-cargo::admin.tbl_courier_officer.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('lavalite-karneaud-cargo::admin.tbl_courier_officer.message', $data)->render();

        }

    }
}
