<?php

namespace Karneaud\LavaliteKarneaudCargo\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Karneaud\LavaliteKarneaudCargo\Http\Requests\TblCourierTrackRequest;
use Karneaud\LavaliteKarneaudCargo\Interfaces\TblCourierTrackRepositoryInterface;
use Karneaud\LavaliteKarneaudCargo\Models\TblCourierTrack;

/**
 * Resource controller class for tbl_courier_track.
 */
class TblCourierTrackResourceController extends BaseController
{

    /**
     * Initialize tbl_courier_track resource controller.
     *
     * @param type TblCourierTrackRepositoryInterface $tbl_courier_track
     *
     * @return null
     */
    public function __construct(TblCourierTrackRepositoryInterface $tbl_courier_track)
    {
        parent::__construct();
        $this->repository = $tbl_courier_track;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Karneaud\LavaliteKarneaudCargo\Repositories\Criteria\TblCourierTrackResourceCriteria::class);
    }

    /**
     * Display a list of tbl_courier_track.
     *
     * @return Response
     */
    public function index(TblCourierTrackRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Karneaud\LavaliteKarneaudCargo\Repositories\Presenter\TblCourierTrackPresenter::class)
                ->$function();
        }

        $tbl_courier_tracks = $this->repository->paginate();

        return $this->response->title(trans('lavalite-karneaud-cargo::tbl_courier_track.names'))
            ->view('lavalite-karneaud-cargo::tbl_courier_track.index', true)
            ->data(compact('tbl_courier_tracks', 'view'))
            ->output();
    }

    /**
     * Display tbl_courier_track.
     *
     * @param Request $request
     * @param Model   $tbl_courier_track
     *
     * @return Response
     */
    public function show(TblCourierTrackRequest $request, TblCourierTrack $tbl_courier_track)
    {

        if ($tbl_courier_track->exists) {
            $view = 'lavalite-karneaud-cargo::tbl_courier_track.show';
        } else {
            $view = 'lavalite-karneaud-cargo::tbl_courier_track.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('lavalite-karneaud-cargo::tbl_courier_track.name'))
            ->data(compact('tbl_courier_track'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new tbl_courier_track.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TblCourierTrackRequest $request)
    {

        $tbl_courier_track = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('lavalite-karneaud-cargo::tbl_courier_track.name')) 
            ->view('lavalite-karneaud-cargo::tbl_courier_track.create', true) 
            ->data(compact('tbl_courier_track'))
            ->output();
    }

    /**
     * Create new tbl_courier_track.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TblCourierTrackRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $tbl_courier_track                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('lavalite-karneaud-cargo::tbl_courier_track.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('lavalite-karneaud-cargo/tbl_courier_track/' . $tbl_courier_track->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/lavalite-karneaud-cargo/tbl_courier_track'))
                ->redirect();
        }

    }

    /**
     * Show tbl_courier_track for editing.
     *
     * @param Request $request
     * @param Model   $tbl_courier_track
     *
     * @return Response
     */
    public function edit(TblCourierTrackRequest $request, TblCourierTrack $tbl_courier_track)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('lavalite-karneaud-cargo::tbl_courier_track.name'))
            ->view('lavalite-karneaud-cargo::tbl_courier_track.edit', true)
            ->data(compact('tbl_courier_track'))
            ->output();
    }

    /**
     * Update the tbl_courier_track.
     *
     * @param Request $request
     * @param Model   $tbl_courier_track
     *
     * @return Response
     */
    public function update(TblCourierTrackRequest $request, TblCourierTrack $tbl_courier_track)
    {
        try {
            $attributes = $request->all();

            $tbl_courier_track->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('lavalite-karneaud-cargo::tbl_courier_track.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('lavalite-karneaud-cargo/tbl_courier_track/' . $tbl_courier_track->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('lavalite-karneaud-cargo/tbl_courier_track/' . $tbl_courier_track->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the tbl_courier_track.
     *
     * @param Model   $tbl_courier_track
     *
     * @return Response
     */
    public function destroy(TblCourierTrackRequest $request, TblCourierTrack $tbl_courier_track)
    {
        try {

            $tbl_courier_track->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('lavalite-karneaud-cargo::tbl_courier_track.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('lavalite-karneaud-cargo/tbl_courier_track/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('lavalite-karneaud-cargo/tbl_courier_track/' . $tbl_courier_track->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple tbl_courier_track.
     *
     * @param Model   $tbl_courier_track
     *
     * @return Response
     */
    public function delete(TblCourierTrackRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('lavalite-karneaud-cargo::tbl_courier_track.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('lavalite-karneaud-cargo/tbl_courier_track'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/lavalite-karneaud-cargo/tbl_courier_track'))
                ->redirect();
        }

    }

    /**
     * Restore deleted tbl_courier_tracks.
     *
     * @param Model   $tbl_courier_track
     *
     * @return Response
     */
    public function restore(TblCourierTrackRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('lavalite-karneaud-cargo::tbl_courier_track.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/lavalite-karneaud-cargo/tbl_courier_track'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/lavalite-karneaud-cargo/tbl_courier_track/'))
                ->redirect();
        }

    }

}
