<?php

namespace Karneaud\LavaliteKarneaudCargo\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Karneaud\LavaliteKarneaudCargo\Http\Requests\TblCourierRequest;
use Karneaud\LavaliteKarneaudCargo\Models\TblCourier;

/**
 * Admin web controller class.
 */
class TblCourierWorkflowController extends BaseController
{

    /**
     * Workflow controller function for tbl_courier.
     *
     * @param Model   $tbl_courier
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(TblCourierRequest $request, TblCourier $tbl_courier, $step)
    {

        try {

            $tbl_courier->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('lavalite-karneaud-cargo::tbl_courier.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/tbl_courier/tbl_courier/' . $tbl_courier->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/tbl_courier/tbl_courier/' . $tbl_courier->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for tbl_courier.
     *
     * @param Model   $tbl_courier
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(TblCourier $tbl_courier, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $tbl_courier->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('lavalite-karneaud-cargo::tbl_courier.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('lavalite-karneaud-cargo::admin.tbl_courier.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('lavalite-karneaud-cargo::admin.tbl_courier.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('lavalite-karneaud-cargo::admin.tbl_courier.message', $data)->render();

        }

    }
}
