<?php

namespace Karneaud\LavaliteKarneaudCargo\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Karneaud\LavaliteKarneaudCargo\Http\Requests\TblOfficeRequest;
use Karneaud\LavaliteKarneaudCargo\Interfaces\TblOfficeRepositoryInterface;
use Karneaud\LavaliteKarneaudCargo\Models\TblOffice;

/**
 * Resource controller class for tbl_office.
 */
class TblOfficeResourceController extends BaseController
{

    /**
     * Initialize tbl_office resource controller.
     *
     * @param type TblOfficeRepositoryInterface $tbl_office
     *
     * @return null
     */
    public function __construct(TblOfficeRepositoryInterface $tbl_office)
    {
        parent::__construct();
        $this->repository = $tbl_office;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Karneaud\LavaliteKarneaudCargo\Repositories\Criteria\TblOfficeResourceCriteria::class);
    }

    /**
     * Display a list of tbl_office.
     *
     * @return Response
     */
    public function index(TblOfficeRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Karneaud\LavaliteKarneaudCargo\Repositories\Presenter\TblOfficePresenter::class)
                ->$function();
        }

        $tbl_offices = $this->repository->paginate();

        return $this->response->title(trans('lavalite-karneaud-cargo::tbl_office.names'))
            ->view('lavalite-karneaud-cargo::tbl_office.index', true)
            ->data(compact('tbl_offices', 'view'))
            ->output();
    }

    /**
     * Display tbl_office.
     *
     * @param Request $request
     * @param Model   $tbl_office
     *
     * @return Response
     */
    public function show(TblOfficeRequest $request, TblOffice $tbl_office)
    {

        if ($tbl_office->exists) {
            $view = 'lavalite-karneaud-cargo::tbl_office.show';
        } else {
            $view = 'lavalite-karneaud-cargo::tbl_office.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('lavalite-karneaud-cargo::tbl_office.name'))
            ->data(compact('tbl_office'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new tbl_office.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TblOfficeRequest $request)
    {

        $tbl_office = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('lavalite-karneaud-cargo::tbl_office.name')) 
            ->view('lavalite-karneaud-cargo::tbl_office.create', true) 
            ->data(compact('tbl_office'))
            ->output();
    }

    /**
     * Create new tbl_office.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TblOfficeRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $tbl_office                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('lavalite-karneaud-cargo::tbl_office.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('lavalite-karneaud-cargo/tbl_office/' . $tbl_office->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/lavalite-karneaud-cargo/tbl_office'))
                ->redirect();
        }

    }

    /**
     * Show tbl_office for editing.
     *
     * @param Request $request
     * @param Model   $tbl_office
     *
     * @return Response
     */
    public function edit(TblOfficeRequest $request, TblOffice $tbl_office)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('lavalite-karneaud-cargo::tbl_office.name'))
            ->view('lavalite-karneaud-cargo::tbl_office.edit', true)
            ->data(compact('tbl_office'))
            ->output();
    }

    /**
     * Update the tbl_office.
     *
     * @param Request $request
     * @param Model   $tbl_office
     *
     * @return Response
     */
    public function update(TblOfficeRequest $request, TblOffice $tbl_office)
    {
        try {
            $attributes = $request->all();

            $tbl_office->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('lavalite-karneaud-cargo::tbl_office.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('lavalite-karneaud-cargo/tbl_office/' . $tbl_office->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('lavalite-karneaud-cargo/tbl_office/' . $tbl_office->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the tbl_office.
     *
     * @param Model   $tbl_office
     *
     * @return Response
     */
    public function destroy(TblOfficeRequest $request, TblOffice $tbl_office)
    {
        try {

            $tbl_office->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('lavalite-karneaud-cargo::tbl_office.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('lavalite-karneaud-cargo/tbl_office/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('lavalite-karneaud-cargo/tbl_office/' . $tbl_office->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple tbl_office.
     *
     * @param Model   $tbl_office
     *
     * @return Response
     */
    public function delete(TblOfficeRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('lavalite-karneaud-cargo::tbl_office.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('lavalite-karneaud-cargo/tbl_office'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/lavalite-karneaud-cargo/tbl_office'))
                ->redirect();
        }

    }

    /**
     * Restore deleted tbl_offices.
     *
     * @param Model   $tbl_office
     *
     * @return Response
     */
    public function restore(TblOfficeRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('lavalite-karneaud-cargo::tbl_office.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/lavalite-karneaud-cargo/tbl_office'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/lavalite-karneaud-cargo/tbl_office/'))
                ->redirect();
        }

    }

}
