<?php

namespace Karneaud\LavaliteKarneaudCargo\Policies;

use Litepie\User\Contracts\UserPolicy;
use Karneaud\LavaliteKarneaudCargo\Models\TblCourier;

class TblCourierPolicy
{

    /**
     * Determine if the given user can view the tbl_courier.
     *
     * @param UserPolicy $user
     * @param TblCourier $tbl_courier
     *
     * @return bool
     */
    public function view(UserPolicy $user, TblCourier $tbl_courier)
    {
        if ($user->canDo('lavalite-karneaud-cargo.tbl_courier.view') && $user->isAdmin()) {
            return true;
        }

        return $tbl_courier->user_id == user_id() && $tbl_courier->user_type == user_type();
    }

    /**
     * Determine if the given user can create a tbl_courier.
     *
     * @param UserPolicy $user
     * @param TblCourier $tbl_courier
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('lavalite-karneaud-cargo.tbl_courier.create');
    }

    /**
     * Determine if the given user can update the given tbl_courier.
     *
     * @param UserPolicy $user
     * @param TblCourier $tbl_courier
     *
     * @return bool
     */
    public function update(UserPolicy $user, TblCourier $tbl_courier)
    {
        if ($user->canDo('lavalite-karneaud-cargo.tbl_courier.edit') && $user->isAdmin()) {
            return true;
        }

        return $tbl_courier->user_id == user_id() && $tbl_courier->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given tbl_courier.
     *
     * @param UserPolicy $user
     * @param TblCourier $tbl_courier
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, TblCourier $tbl_courier)
    {
        return $tbl_courier->user_id == user_id() && $tbl_courier->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given tbl_courier.
     *
     * @param UserPolicy $user
     * @param TblCourier $tbl_courier
     *
     * @return bool
     */
    public function verify(UserPolicy $user, TblCourier $tbl_courier)
    {
        if ($user->canDo('lavalite-karneaud-cargo.tbl_courier.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given tbl_courier.
     *
     * @param UserPolicy $user
     * @param TblCourier $tbl_courier
     *
     * @return bool
     */
    public function approve(UserPolicy $user, TblCourier $tbl_courier)
    {
        if ($user->canDo('lavalite-karneaud-cargo.tbl_courier.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
