<?php

namespace Karneaud\LavaliteKarneaudCargo\Policies;

use Litepie\User\Contracts\UserPolicy;
use Karneaud\LavaliteKarneaudCargo\Models\TblOffice;

class TblOfficePolicy
{

    /**
     * Determine if the given user can view the tbl_office.
     *
     * @param UserPolicy $user
     * @param TblOffice $tbl_office
     *
     * @return bool
     */
    public function view(UserPolicy $user, TblOffice $tbl_office)
    {
        if ($user->canDo('lavalite-karneaud-cargo.tbl_office.view') && $user->isAdmin()) {
            return true;
        }

        return $tbl_office->user_id == user_id() && $tbl_office->user_type == user_type();
    }

    /**
     * Determine if the given user can create a tbl_office.
     *
     * @param UserPolicy $user
     * @param TblOffice $tbl_office
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('lavalite-karneaud-cargo.tbl_office.create');
    }

    /**
     * Determine if the given user can update the given tbl_office.
     *
     * @param UserPolicy $user
     * @param TblOffice $tbl_office
     *
     * @return bool
     */
    public function update(UserPolicy $user, TblOffice $tbl_office)
    {
        if ($user->canDo('lavalite-karneaud-cargo.tbl_office.edit') && $user->isAdmin()) {
            return true;
        }

        return $tbl_office->user_id == user_id() && $tbl_office->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given tbl_office.
     *
     * @param UserPolicy $user
     * @param TblOffice $tbl_office
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, TblOffice $tbl_office)
    {
        return $tbl_office->user_id == user_id() && $tbl_office->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given tbl_office.
     *
     * @param UserPolicy $user
     * @param TblOffice $tbl_office
     *
     * @return bool
     */
    public function verify(UserPolicy $user, TblOffice $tbl_office)
    {
        if ($user->canDo('lavalite-karneaud-cargo.tbl_office.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given tbl_office.
     *
     * @param UserPolicy $user
     * @param TblOffice $tbl_office
     *
     * @return bool
     */
    public function approve(UserPolicy $user, TblOffice $tbl_office)
    {
        if ($user->canDo('lavalite-karneaud-cargo.tbl_office.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
