<?php

namespace Karneaud\LavaliteKarneaudCargo\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Karneaud\LavaliteKarneaudCargo\Models\LavaliteKarneaudCargo;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Karneaud\LavaliteKarneaudCargo\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/lavalite-karneaud-cargo/tbl_courier/*')) {
            Route::bind('tbl_courier', function ($tbl_courier) {
                $tbl_courierrepo = $this->app->make('Karneaud\LavaliteKarneaudCargo\Interfaces\TblCourierRepositoryInterface');
                return $tbl_courierrepo->findorNew($tbl_courier);
            });
        }

        if (Request::is('*/lavalite-karneaud-cargo/tbl_courier_officer/*')) {
            Route::bind('tbl_courier_officer', function ($tbl_courier_officer) {
                $tbl_courier_officerrepo = $this->app->make('Karneaud\LavaliteKarneaudCargo\Interfaces\TblCourierOfficerRepositoryInterface');
                return $tbl_courier_officerrepo->findorNew($tbl_courier_officer);
            });
        }

        if (Request::is('*/lavalite-karneaud-cargo/tbl_courier_track/*')) {
            Route::bind('tbl_courier_track', function ($tbl_courier_track) {
                $tbl_courier_trackrepo = $this->app->make('Karneaud\LavaliteKarneaudCargo\Interfaces\TblCourierTrackRepositoryInterface');
                return $tbl_courier_trackrepo->findorNew($tbl_courier_track);
            });
        }

        if (Request::is('*/lavalite-karneaud-cargo/tbl_office/*')) {
            Route::bind('tbl_office', function ($tbl_office) {
                $tbl_officerepo = $this->app->make('Karneaud\LavaliteKarneaudCargo\Interfaces\TblOfficeRepositoryInterface');
                return $tbl_officerepo->findorNew($tbl_office);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        if(request()->segment(1) != 'api' && request()->segment(2) != 'api') {
            return;
        }

        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale() . '/api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
