<?php

namespace Karneaud\LavaliteKarneaudCargo\Providers;

use Litepie\Contracts\Workflow\Workflow as WorkflowContract;
use Litepie\Foundation\Support\Providers\WorkflowServiceProvider as ServiceProvider;

class WorkflowServiceProvider extends ServiceProvider
{
    /**
     * The validators mappings for the package.
     *
     * @var array
     */
    protected $validators = [
        // Bind TblCourier workflow validator
        'Karneaud\LavaliteKarneaudCargo\Models\TblCourier' => \Karneaud\LavaliteKarneaudCargo\Workflow\TblCourierValidator::class,

        // Bind TblCourierOfficer workflow validator
        'Karneaud\LavaliteKarneaudCargo\Models\TblCourierOfficer' => \Karneaud\LavaliteKarneaudCargo\Workflow\TblCourierOfficerValidator::class,

        // Bind TblCourierTrack workflow validator
        'Karneaud\LavaliteKarneaudCargo\Models\TblCourierTrack' => \Karneaud\LavaliteKarneaudCargo\Workflow\TblCourierTrackValidator::class,

        // Bind TblOffice workflow validator
        'Karneaud\LavaliteKarneaudCargo\Models\TblOffice' => \Karneaud\LavaliteKarneaudCargo\Workflow\TblOfficeValidator::class,
    ];

    /**
     * The actions mappings for the package.
     *
     * @var array
     */
    protected $actions = [
        // Bind TblCourier workflow actions
        'Karneaud\LavaliteKarneaudCargo\Models\TblCourier' => \Karneaud\LavaliteKarneaudCargo\Workflow\TblCourierAction::class,

        // Bind TblCourierOfficer workflow actions
        'Karneaud\LavaliteKarneaudCargo\Models\TblCourierOfficer' => \Karneaud\LavaliteKarneaudCargo\Workflow\TblCourierOfficerAction::class,

        // Bind TblCourierTrack workflow actions
        'Karneaud\LavaliteKarneaudCargo\Models\TblCourierTrack' => \Karneaud\LavaliteKarneaudCargo\Workflow\TblCourierTrackAction::class,

        // Bind TblOffice workflow actions
        'Karneaud\LavaliteKarneaudCargo\Models\TblOffice' => \Karneaud\LavaliteKarneaudCargo\Workflow\TblOfficeAction::class,
    ];

    /**
     * The notifiers mappings for the package.
     *
     * @var array
     */
    protected $notifiers = [
       // Bind TblCourier workflow notifiers
        'Karneaud\LavaliteKarneaudCargo\Models\TblCourier' => \Karneaud\LavaliteKarneaudCargo\Workflow\TblCourierNotifier::class,

        // Bind TblCourierOfficer workflow notifiers
        'Karneaud\LavaliteKarneaudCargo\Models\TblCourierOfficer' => \Karneaud\LavaliteKarneaudCargo\Workflow\TblCourierOfficerNotifier::class,

        // Bind TblCourierTrack workflow notifiers
        'Karneaud\LavaliteKarneaudCargo\Models\TblCourierTrack' => \Karneaud\LavaliteKarneaudCargo\Workflow\TblCourierTrackNotifier::class,

        // Bind TblOffice workflow notifiers
        'Karneaud\LavaliteKarneaudCargo\Models\TblOffice' => \Karneaud\LavaliteKarneaudCargo\Workflow\TblOfficeNotifier::class,
    ];

    /**
     * Register any package workflow validation services.
     *
     * @param \Litepie\Contracts\Workflow\Workflow $workflow
     *
     * @return void
     */
    public function boot(WorkflowContract $workflow)
    {
        parent::registerValidators($workflow);
        parent::registerActions($workflow);
        parent::registerNotifiers($workflow);
    }
}
