<?php

namespace Karneaud\LavaliteKarneaudCargo\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Karneaud\LavaliteKarneaudCargo\Models\TblCourierOfficer;

class TblCourierOfficerAction
{
    /**
     * Perform the complete action.
     *
     * @param TblCourierOfficer $tbl_courier_officer
     *
     * @return TblCourierOfficer
     */
    public function complete(TblCourierOfficer $tbl_courier_officer)
    {
        try {
            $tbl_courier_officer->status = 'complete';
            return $tbl_courier_officer->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param TblCourierOfficer $tbl_courier_officer
     *
     * @return TblCourierOfficer
     */public function verify(TblCourierOfficer $tbl_courier_officer)
    {
        try {
            $tbl_courier_officer->status = 'verify';
            return $tbl_courier_officer->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param TblCourierOfficer $tbl_courier_officer
     *
     * @return TblCourierOfficer
     */public function approve(TblCourierOfficer $tbl_courier_officer)
    {
        try {
            $tbl_courier_officer->status = 'approve';
            return $tbl_courier_officer->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param TblCourierOfficer $tbl_courier_officer
     *
     * @return TblCourierOfficer
     */public function publish(TblCourierOfficer $tbl_courier_officer)
    {
        try {
            $tbl_courier_officer->status = 'publish';
            return $tbl_courier_officer->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param TblCourierOfficer $tbl_courier_officer
     *
     * @return TblCourierOfficer
     */
    public function archive(TblCourierOfficer $tbl_courier_officer)
    {
        try {
            $tbl_courier_officer->status = 'archive';
            return $tbl_courier_officer->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param TblCourierOfficer $tbl_courier_officer
     *
     * @return TblCourierOfficer
     */
    public function unpublish(TblCourierOfficer $tbl_courier_officer)
    {
        try {
            $tbl_courier_officer->status = 'unpublish';
            return $tbl_courier_officer->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
