<?php

namespace Karneaud\LavaliteKarneaudCargo\Workflow;

use Karneaud\LavaliteKarneaudCargo\Models\TblCourierOfficer;
use Validator;

class TblCourierOfficerValidator
{

    /**
     * Determine if the given tbl_courier_officer is valid for complete status.
     *
     * @param TblCourierOfficer $tbl_courier_officer
     *
     * @return bool / Validator
     */
    public function complete(TblCourierOfficer $tbl_courier_officer)
    {
        return Validator::make($tbl_courier_officer->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given tbl_courier_officer is valid for verify status.
     *
     * @param TblCourierOfficer $tbl_courier_officer
     *
     * @return bool / Validator
     */
    public function verify(TblCourierOfficer $tbl_courier_officer)
    {
        return Validator::make($tbl_courier_officer->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given tbl_courier_officer is valid for approve status.
     *
     * @param TblCourierOfficer $tbl_courier_officer
     *
     * @return bool / Validator
     */
    public function approve(TblCourierOfficer $tbl_courier_officer)
    {
        return Validator::make($tbl_courier_officer->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given tbl_courier_officer is valid for publish status.
     *
     * @param TblCourierOfficer $tbl_courier_officer
     *
     * @return bool / Validator
     */
    public function publish(TblCourierOfficer $tbl_courier_officer)
    {
        return Validator::make($tbl_courier_officer->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given tbl_courier_officer is valid for archive status.
     *
     * @param TblCourierOfficer $tbl_courier_officer
     *
     * @return bool / Validator
     */
    public function archive(TblCourierOfficer $tbl_courier_officer)
    {
        return Validator::make($tbl_courier_officer->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given tbl_courier_officer is valid for unpublish status.
     *
     * @param TblCourierOfficer $tbl_courier_officer
     *
     * @return bool / Validator
     */
    public function unpublish(TblCourierOfficer $tbl_courier_officer)
    {
        return Validator::make($tbl_courier_officer->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
