<?php

namespace Karneaud\LavaliteKarneaudCargo\Workflow;

use Karneaud\LavaliteKarneaudCargo\Models\TblCourierTrack;
use Validator;

class TblCourierTrackValidator
{

    /**
     * Determine if the given tbl_courier_track is valid for complete status.
     *
     * @param TblCourierTrack $tbl_courier_track
     *
     * @return bool / Validator
     */
    public function complete(TblCourierTrack $tbl_courier_track)
    {
        return Validator::make($tbl_courier_track->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given tbl_courier_track is valid for verify status.
     *
     * @param TblCourierTrack $tbl_courier_track
     *
     * @return bool / Validator
     */
    public function verify(TblCourierTrack $tbl_courier_track)
    {
        return Validator::make($tbl_courier_track->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given tbl_courier_track is valid for approve status.
     *
     * @param TblCourierTrack $tbl_courier_track
     *
     * @return bool / Validator
     */
    public function approve(TblCourierTrack $tbl_courier_track)
    {
        return Validator::make($tbl_courier_track->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given tbl_courier_track is valid for publish status.
     *
     * @param TblCourierTrack $tbl_courier_track
     *
     * @return bool / Validator
     */
    public function publish(TblCourierTrack $tbl_courier_track)
    {
        return Validator::make($tbl_courier_track->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given tbl_courier_track is valid for archive status.
     *
     * @param TblCourierTrack $tbl_courier_track
     *
     * @return bool / Validator
     */
    public function archive(TblCourierTrack $tbl_courier_track)
    {
        return Validator::make($tbl_courier_track->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given tbl_courier_track is valid for unpublish status.
     *
     * @param TblCourierTrack $tbl_courier_track
     *
     * @return bool / Validator
     */
    public function unpublish(TblCourierTrack $tbl_courier_track)
    {
        return Validator::make($tbl_courier_track->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
