<?php

namespace Karneaud\LavaliteKarneaudCargo\Workflow;

use Karneaud\LavaliteKarneaudCargo\Models\TblCourier;
use Validator;

class TblCourierValidator
{

    /**
     * Determine if the given tbl_courier is valid for complete status.
     *
     * @param TblCourier $tbl_courier
     *
     * @return bool / Validator
     */
    public function complete(TblCourier $tbl_courier)
    {
        return Validator::make($tbl_courier->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given tbl_courier is valid for verify status.
     *
     * @param TblCourier $tbl_courier
     *
     * @return bool / Validator
     */
    public function verify(TblCourier $tbl_courier)
    {
        return Validator::make($tbl_courier->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given tbl_courier is valid for approve status.
     *
     * @param TblCourier $tbl_courier
     *
     * @return bool / Validator
     */
    public function approve(TblCourier $tbl_courier)
    {
        return Validator::make($tbl_courier->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given tbl_courier is valid for publish status.
     *
     * @param TblCourier $tbl_courier
     *
     * @return bool / Validator
     */
    public function publish(TblCourier $tbl_courier)
    {
        return Validator::make($tbl_courier->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given tbl_courier is valid for archive status.
     *
     * @param TblCourier $tbl_courier
     *
     * @return bool / Validator
     */
    public function archive(TblCourier $tbl_courier)
    {
        return Validator::make($tbl_courier->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given tbl_courier is valid for unpublish status.
     *
     * @param TblCourier $tbl_courier
     *
     * @return bool / Validator
     */
    public function unpublish(TblCourier $tbl_courier)
    {
        return Validator::make($tbl_courier->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
