<?php

namespace Karneaud\LavaliteKarneaudCargo\Workflow;

use Karneaud\LavaliteKarneaudCargo\Models\TblOffice;
use Validator;

class TblOfficeValidator
{

    /**
     * Determine if the given tbl_office is valid for complete status.
     *
     * @param TblOffice $tbl_office
     *
     * @return bool / Validator
     */
    public function complete(TblOffice $tbl_office)
    {
        return Validator::make($tbl_office->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given tbl_office is valid for verify status.
     *
     * @param TblOffice $tbl_office
     *
     * @return bool / Validator
     */
    public function verify(TblOffice $tbl_office)
    {
        return Validator::make($tbl_office->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given tbl_office is valid for approve status.
     *
     * @param TblOffice $tbl_office
     *
     * @return bool / Validator
     */
    public function approve(TblOffice $tbl_office)
    {
        return Validator::make($tbl_office->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given tbl_office is valid for publish status.
     *
     * @param TblOffice $tbl_office
     *
     * @return bool / Validator
     */
    public function publish(TblOffice $tbl_office)
    {
        return Validator::make($tbl_office->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given tbl_office is valid for archive status.
     *
     * @param TblOffice $tbl_office
     *
     * @return bool / Validator
     */
    public function archive(TblOffice $tbl_office)
    {
        return Validator::make($tbl_office->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given tbl_office is valid for unpublish status.
     *
     * @param TblOffice $tbl_office
     *
     * @return bool / Validator
     */
    public function unpublish(TblOffice $tbl_office)
    {
        return Validator::make($tbl_office->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
